@@ -23,8 +23,11 @@
 
 package ch.kuramo.javie.api;
 
-import ch.kuramo.javie.api.Vec3d;
-
+/**
+ * アニメーション可能な{@link Vec3d}型のプロパティを表すインターフェースです。
+ * このインターフェースは <i>不透明型</i> であり、メソッド等はありません。
+ * 使用方法は {@link IAnimatableDouble} をご覧ください。
+ */
 public interface IAnimatableVec3d extends IAnimatableValue<Vec3d> {
 
 }
