@@ -35,13 +35,10 @@ import org.eclipse.core.runtime.IExtensionRegistry;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.GroupMarker;
-import org.eclipse.jface.action.ICoolBarManager;
 import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
+import org.eclipse.jface.action.IStatusLineManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
-import org.eclipse.jface.action.ToolBarContributionItem;
-import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.swt.SWT;
 import org.eclipse.ui.IWorkbenchActionConstants;
 import org.eclipse.ui.IWorkbenchWindow;
@@ -434,13 +431,10 @@ public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
 		helpMenu.add(aboutAction);
 	}
 
-	protected void fillCoolBar(ICoolBarManager coolBar) {
-		IToolBarManager toolBar = new ToolBarManager(SWT.FLAT | SWT.RIGHT);
-		coolBar.add(new ToolBarContributionItem(toolBar, "main"));
-
+	protected void fillStatusLine(IStatusLineManager statusLine) {
 		GLCanvasFactory glCanavsFactory = GLCanvasFactory.getFactory();
 		if (glCanavsFactory.isPoolMode()) {
-			toolBar.add(glCanavsFactory.createControlContribution());
+			statusLine.add(glCanavsFactory.createControlContribution());
 		}
 	}
 
