@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -586,6 +586,12 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 			case LAYERS_REMOVE:
 			case LAYERS_REORDER:
 			case LAYER_EXPRESSION_CHANGE:
+			case TEXT_ANIMATORS_ADD:
+			case TEXT_ANIMATORS_REMOVE:
+			case TA_SELECTORS_ADD:
+			case TA_SELECTORS_REMOVE:
+			case TA_PROPERTIES_ADD:
+			case TA_PROPERTIES_REMOVE:
 			case EFFECT_PROPERTY_CHANGE:
 			case EFFECTS_ADD:
 			case EFFECTS_REMOVE:
