@@ -71,7 +71,7 @@ public class AnimatableEnumElementDelegate<E extends Enum<E>> extends Animatable
 			if (EnumLabels.insertSeparator(e)) {
 				new MenuItem(menu, SWT.SEPARATOR);
 			}
-			Action action = new Action(EnumLabels.getLabel(e), IAction.AS_RADIO_BUTTON) {
+			Action action = new Action(EnumLabels.getLabel(e).replaceAll("&", "&&"), IAction.AS_RADIO_BUTTON) {
 				public void run() {
 					if (e != value) {
 						modifyValue(e);
