@@ -509,7 +509,7 @@ public class LayerElement extends Element {
 				label = String.format("%s - %s", EnumLabels.getLabel(tm), getName(getTrackMatteLayer()));
 			}
 
-			Action action = new Action(label, IAction.AS_RADIO_BUTTON) {
+			Action action = new Action(label.replaceAll("&", "&&"), IAction.AS_RADIO_BUTTON) {
 				public void run() {
 					if (current != tm) {
 						ProjectManager pm = (ProjectManager) viewer.getData(LayerCompositionView.PROJECT_MANAGER);
@@ -543,7 +543,7 @@ public class LayerElement extends Element {
 		new MenuItem(menu, SWT.SEPARATOR);
 
 		for (final Layer otherLayer : composition.getLayers()) {
-			action = new Action(getName(otherLayer), IAction.AS_RADIO_BUTTON) {
+			action = new Action(getName(otherLayer).replaceAll("&", "&&"), IAction.AS_RADIO_BUTTON) {
 				public void run() {
 					if (currentParent != otherLayer) {
 						ProjectManager pm = (ProjectManager) viewer.getData(LayerCompositionView.PROJECT_MANAGER);
