@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -111,7 +111,7 @@ public class AnimatableVec3d extends ArithmeticalAnimatableValue<Vec3d> implemen
 				prepareSlerpModeCatmullRom(p1, p2);
 				prepareSlerpModeCatmullRom(p2, p3);
 
-				return valueOf(catmullRom(p0, p1, p2, p3, k1.time, k2.time, time));
+				return valueOf(catmullRom(p0, p1, p2, p3, k0.time, k1.time, k2.time, k3.time, time));
 			}
 
 			default:
