@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -143,8 +143,9 @@ public abstract class ArithmeticalAnimatableValue<V> extends AbstractAnimatableV
 				SortedMap<Time, Keyframe<V>> headMap = _keyframes.headMap(k1.time);
 				Keyframe<V> k0 = !headMap.isEmpty() ? headMap.get(headMap.lastKey()) : k1;
 				Keyframe<V> k3 = tail.hasNext() ? tail.next().getValue() : k2;
-				return valueOf(catmullRom(toArray(k0.value), toArray(k1.value),
-						toArray(k2.value), toArray(k3.value), k1.time, k2.time, time));
+				return valueOf(catmullRom(
+						toArray(k0.value), toArray(k1.value), toArray(k2.value), toArray(k3.value),
+						k0.time, k1.time, k2.time, k3.time, time));
 			}
 
 			default:
@@ -157,32 +158,34 @@ public abstract class ArithmeticalAnimatableValue<V> extends AbstractAnimatableV
 	protected abstract V valueOf(double[] d);
 
 	protected double[] linear(double[] p1, double[] p2, Time time1, Time time2, Time time) {
+		double s1 = time1.toSecond();
+		double s2 = time2.toSecond();
+		double s = time.toSecond();
+		double t = (s - s1) / (s2 - s1);
+
 		double[] result = new double[p1.length];
 		for (int i = 0, n = result.length; i < n; ++i) {
-			double s1 = time1.toSecond();
-			double s2 = time2.toSecond();
-			double s = time.toSecond();
-
-			double t = (s - s1) / (s2 - s1);
-
 			result[i] = (p2[i] - p1[i]) * t + p1[i];
 		}
 		return result;
 	}
 
 	protected double[] catmullRom(
-			double[] p0, double[] p1, double[] p2, double[] p3, Time time1, Time time2, Time time) {
+			double[] p0, double[] p1, double[] p2, double[] p3,
+			Time time0, Time time1, Time time2, Time time3, Time time) {
+
+//		double s0 = time0.toSecond();
+		double s1 = time1.toSecond();
+		double s2 = time2.toSecond();
+//		double s3 = time3.toSecond();
+		double s = time.toSecond();
+
+		double t = (s - s1) / (s2 - s1);
+		double tt = t*t;
+		double ttt = tt*t;
 
 		double[] result = new double[p0.length];
 		for (int i = 0, n = result.length; i < n; ++i) {
-			double s1 = time1.toSecond();
-			double s2 = time2.toSecond();
-			double s = time.toSecond();
-
-			double t = (s - s1) / (s2 - s1);
-			double tt = t*t;
-			double ttt = tt*t;
-
 			double v0 = (p2[i] - p0[i]) * 0.5;
 			double v1 = (p3[i] - p1[i]) * 0.5;
 			result[i] = (2*p1[i] - 2*p2[i] + v0 + v1)*ttt + (-3*p1[i] + 3*p2[i] - 2*v0 - v1)*tt + v0*t + p1[i];
