@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -34,6 +34,7 @@ import ch.kuramo.javie.api.services.IBlendSupport;
 import ch.kuramo.javie.api.services.IBlurSupport;
 import ch.kuramo.javie.api.services.IConvolutionSupport;
 import ch.kuramo.javie.api.services.IShaderRegistry;
+import ch.kuramo.javie.api.services.ITexture1DSupport;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.core.internal.services.AccumulationSupportImpl;
@@ -58,6 +59,7 @@ import ch.kuramo.javie.core.internal.services.ProjectEncoderImpl;
 import ch.kuramo.javie.core.internal.services.RenderContextProxy;
 import ch.kuramo.javie.core.internal.services.ShaderRegistryImpl;
 import ch.kuramo.javie.core.internal.services.SynchronousTaskThreadImpl;
+import ch.kuramo.javie.core.internal.services.Texture1DSupportImpl;
 import ch.kuramo.javie.core.internal.services.VideoEffectContextProxy;
 import ch.kuramo.javie.core.internal.services.VideoEffectPipelineImpl;
 import ch.kuramo.javie.core.internal.services.VideoRenderSupportImpl;
@@ -157,6 +159,10 @@ public class JavieCoreModule extends AbstractModule {
 				.to(AccumulationSupportImpl.class)
 				.in(Scopes.SINGLETON);
 
+		bind(ITexture1DSupport.class)
+				.to(Texture1DSupportImpl.class)
+				.in(Scopes.SINGLETON);
+
 		bind(FontList.class)
 				.to(FontListImpl.class)
 				.in(Scopes.SINGLETON);
