@@ -369,7 +369,7 @@ public class FractalNoise {
 			Runnable operation = new Runnable() {
 				public void run() {
 					GL2 gl = context.getGL().getGL2();
-					int permTexture = FractalNoiseTexture.getPermTexture(gl);
+					int permTexture = NoiseTexture.getPermTexture(gl);
 
 					gl.glActiveTexture(GL2.GL_TEXTURE0);
 					gl.glBindTexture(GL2.GL_TEXTURE_2D, permTexture);
